/*************************************************************************/
/* Copyright (c) 2004                                                    */
/* Daniel Sleator, David Temperley, and John Lafferty                    */
/* All rights reserved                                                   */
/*                                                                       */
/* Use of the link grammar parsing system is subject to the terms of the */
/* license set forth in the LICENSE file included with this software.    */
/* This license allows free redistribution and use in source and binary  */
/* forms, with or without modification, subject to certain conditions.   */
/*                                                                       */
/*************************************************************************/

#include "dict-structures.h"
#include "link-includes.h"
#include "utilities.h"

void insert_idiom(Dictionary dict, Dict_node *);
bool contains_underbar(const char *) ATTR_PURE;
bool is_idiom_word(const char *) ATTR_PURE;
